@@ -6,12 +6,11 @@ __path__ = (os.path.dirname(__file__), )
 with open(os.path.join(__path__[0], '__init__.py')) as f:
     init_text = f.read()
     __version__ = re.search(r'__version__\s*=\s*[\'\"](.+?)[\'\"]', init_text).group(1)
-import io
 import sys
 import ast
 import json
+import copy
 import logging
-import requests
 import warnings
 warnings.simplefilter(action='ignore', category=FutureWarning)
 warnings.simplefilter(action='ignore', category=Warning)
@@ -43,6 +42,8 @@ from onnx2tf.utils.common_functions import (
     dummy_onnx_inference,
     dummy_tf_inference,
     onnx_tf_tensor_validation,
+    weights_export,
+    download_test_image_data,
 )
 from onnx2tf.utils.colors import Color
 from sng4onnx import generate as op_name_auto_generate
@@ -54,6 +55,7 @@ def convert(
     output_folder_path: Optional[str] = 'saved_model',
     output_signaturedefs: Optional[bool] = False,
     output_h5: Optional[bool] = False,
+    output_weights: Optional[bool] = False,
     output_integer_quantized_tflite: Optional[bool] = False,
     quant_type: Optional[str] = 'per-channel',
     quant_calib_input_op_name_np_data_path: Optional[List] = None,
@@ -69,6 +71,7 @@ def convert(
     disable_group_convolution: Optional[bool] = False,
     enable_batchmatmul_unfold: Optional[bool] = False,
     disable_suppression_flextranspose: Optional[bool] = False,
+    number_of_dimensions_after_flextranspose_compression: Optional[int] = 5,
     replace_argmax_to_reducemax_and_indicies_is_int64: Optional[bool] = False,
     replace_argmax_to_reducemax_and_indicies_is_float32: Optional[bool] = False,
     replace_argmax_to_fused_argmax_and_indicies_is_int64: Optional[bool] = False,
@@ -87,8 +90,10 @@ def convert(
     param_replacement_file: Optional[str] = '',
     check_gpu_delegate_compatibility: Optional[bool] = False,
     check_onnx_tf_outputs_elementwise_close: Optional[bool] = False,
-    check_onnx_tf_outputs_elementwise_close_rtol: Optional[float] = 1e-5,
-    check_onnx_tf_outputs_elementwise_close_atol: Optional[float] = 1e-5,
+    check_onnx_tf_outputs_elementwise_close_full: Optional[bool] = False,
+    check_onnx_tf_outputs_sample_data_normalization: Optional[str] = 'norm',
+    check_onnx_tf_outputs_elementwise_close_rtol: Optional[float] = 0.0,
+    check_onnx_tf_outputs_elementwise_close_atol: Optional[float] = 1e-4,
     mvn_epsilon: Optional[float] = 0.0000000001,
     non_verbose: Optional[bool] = False,
 ) -> tf.keras.Model:
@@ -115,7 +120,10 @@ def convert(
         of model conversion and significant increase the size of the model.
 
     output_h5: Optional[bool]
-        Output in Keras H5 format.
+        Output model in Keras (hdf5) format.
+
+    output_weights: Optional[bool]
+        Output weights in hdf5 format.
 
     output_integer_quantized_tflite: Optional[bool]
         Output of integer quantized tflite.
@@ -245,6 +253,10 @@ def convert(
     disable_suppression_flextranspose: Optional[bool]
         Disables FlexTranspose generation suppression.
 
+    number_of_dimensions_after_flextranspose_compression: Optional[int]
+        Number of Transpose OP dimensions generated after avoiding FlexTranspose generation.\n
+        Default: 5
+
     replace_argmax_to_reducemax_and_indicies_is_int64: Optional[bool]
         Replace ArgMax with a ReduceMax. The returned indicies are int64.\n
         Only one of replace_argmax_to_reducemax_and_indicies_is_int64 and \n
@@ -333,16 +345,44 @@ def convert(
         to check if the model can be supported by GPU Delegate.
 
     check_onnx_tf_outputs_elementwise_close: Optional[bool]
-        Returns true if the two arrays, the output of onnx and the output of TF,\n
-        are elementwise close within an acceptable range.
+        Returns "Matches" if the output of onnx and the output of TF are\n
+        within acceptable proximity element by element.\n
+        Returns "Unmatched" if the output of onnx and the output of TF are\n
+        not within acceptable proximity element by element.\n
+        If the output of onnx is 1D, it returns "Skipped" and skips the comparison\n
+        between the output of onnx and that of TF. This is because when undefined\n
+        dimensions are present, a situation often arises where very large index\n
+        values are compared, causing OutOfMemory.\n
+        Only the output content of the models final output OP is checked.
+
+    check_onnx_tf_outputs_elementwise_close_full: Optional[bool]
+        Returns "Matches" if the output of onnx and the output of TF are\n
+        within acceptable proximity element by element.\n
+        Check the output of all OPs in sequence from the beginning,\n
+        including all but the final output OP of the model.\n
+        Returns "Unmatched" if the output of onnx and the output of TF are\n
+        not within acceptable proximity element by element.\n
+        If the output of onnx is 1D, it returns "Skipped" and skips the comparison\n
+        between the output of onnx and that of TF. This is because when undefined\n
+        dimensions are present, a situation often arises where very large index\n
+        values are compared, causing OutOfMemory.\n
+        It is very time consuming because it performs as many inferences as\n
+        there are operations.
+
+    check_onnx_tf_outputs_sample_data_normalization: Optional[str]
+        norm: Validate using random data normalized to the range 0.0 to 1.0\n
+        denorm: Validate using random data in the range 0.0 to 255.0\n
+        If there is a normalization layer at the model's entry point,\n
+        or if the model was trained on denormalized data, "denorm" must be specified.\n
+        Default: "norm"
 
     check_onnx_tf_outputs_elementwise_close_rtol: Optional[float]
         The relative tolerance parameter.\n
-        Default: 1e-5
+        Default: 0.0
 
     check_onnx_tf_outputs_elementwise_close_atol: Optional[float]
         The absolute tolerance parameter.\n
-        Default: 1e-5
+        Default: 1e-4
 
     non_verbose: Optional[bool]
         Do not show all information logs. Only error logs are displayed.\n
@@ -419,12 +459,23 @@ def convert(
     # fused_argmax_scale_ratio
     if ra_option_list.count(True) > 0 and not (0.0 < fused_argmax_scale_ratio <= 1.0):
         print(
+            f'{Color.RED}ERROR:{Color.RESET} ' +
             f'fused_argmax_scale_ratio must be specified in the range '+
             f'0.0 < fused_argmax_scale_ratio <= 1.0. '+
             f'fused_argmax_scale_ratio: {fused_argmax_scale_ratio}'
         )
         sys.exit(1)
 
+    # number_of_dimensions_after_flextranspose_compression
+    if number_of_dimensions_after_flextranspose_compression < 2:
+        print(
+            f'{Color.RED}ERROR:{Color.RESET} ' +
+            f'number_of_dimensions_after_flextranspose_compression must be at least 2. '+
+            f'number_of_dimensions_after_flextranspose_compression: ' +
+            f'{number_of_dimensions_after_flextranspose_compression}'
+        )
+        sys.exit(1)
+
     replacement_parameters = None
     if param_replacement_file:
         if not os.path.isfile(param_replacement_file):
@@ -512,6 +563,36 @@ def convert(
 
     graph = gs.import_onnx(onnx_graph)
 
+    # List Output
+    # Cut the ONNX graph when an output name is specified that interrupts the conversion
+    if not output_names_to_interrupt_model_conversion:
+        output_names = [
+            graph_output.name for graph_output in graph.outputs
+        ]
+    else:
+        try:
+            from sne4onnx import extraction
+        except Exception as ex:
+            print(
+                f'{Color.RED}ERROR:{Color.RESET} ' +\
+                f'If --output_names_to_interrupt_model_conversion is specified, ' +\
+                f'you must install sne4onnx. pip install sne4onnx'
+            )
+            sys.exit(1)
+        # Cut ONNX graph at specified output position
+        output_names = [
+            output_op_name \
+                for output_op_name in output_names_to_interrupt_model_conversion
+        ]
+        onnx_graph = extraction(
+            input_op_names=[graph_input.name for graph_input in graph.inputs],
+            output_op_names=output_names,
+            onnx_graph=onnx_graph,
+        )
+        # Re-import of onnx_graph
+        del graph
+        graph = gs.import_onnx(onnx_graph)
+
     if not non_verbose:
         print('')
         print(f'{Color.REVERCE}Model loaded{Color.RESET}', '=' * 72)
@@ -527,6 +608,7 @@ def convert(
         'non_verbose': non_verbose,
         'disable_group_convolution': disable_group_convolution,
         'disable_suppression_flextranspose': disable_suppression_flextranspose,
+        'number_of_dimensions_after_flextranspose_compression': number_of_dimensions_after_flextranspose_compression,
         'replace_argmax_to_reducemax_and_indicies_is_int64': replace_argmax_to_reducemax_and_indicies_is_int64,
         'replace_argmax_to_reducemax_and_indicies_is_float32': replace_argmax_to_reducemax_and_indicies_is_float32,
         'replace_argmax_to_fused_argmax_and_indicies_is_int64': replace_argmax_to_fused_argmax_and_indicies_is_int64,
@@ -627,16 +709,6 @@ def convert(
                 for layer_info in tf_layers_dict.values() \
                     if layer_info['optype'] == 'Input'
         ]
-
-        # List Output
-        if not output_names_to_interrupt_model_conversion:
-            output_names = [
-                graph_output.name for graph_output in graph.outputs
-            ]
-        else:
-            output_names = [
-                output_op_name for output_op_name in output_names_to_interrupt_model_conversion
-            ]
         outputs = [
             layer_info['tf_node'] \
                 for opname, layer_info in tf_layers_dict.items() \
@@ -724,6 +796,11 @@ def convert(
         tflite_model = converter.convert()
         with open(f'{output_folder_path}/model_float32.tflite', 'wb') as w:
             w.write(tflite_model)
+        if output_weights:
+            weights_export(
+                extract_target_tflite_file_path=f'{output_folder_path}/model_float32.tflite',
+                output_weights_file_path=f'{output_folder_path}/model_float32_weights.h5',
+            )
         if not non_verbose:
             print(f'{Color.GREEN}Float32 tflite output complete!{Color.RESET}')
 
@@ -736,6 +813,11 @@ def convert(
         tflite_model = converter.convert()
         with open(f'{output_folder_path}/model_float16.tflite', 'wb') as w:
             w.write(tflite_model)
+        if output_weights:
+            weights_export(
+                extract_target_tflite_file_path=f'{output_folder_path}/model_float16.tflite',
+                output_weights_file_path=f'{output_folder_path}/model_float16_weights.h5',
+            )
         if not non_verbose:
             print(f'{Color.GREEN}Float16 tflite output complete!{Color.RESET}')
 
@@ -758,6 +840,8 @@ def convert(
                     )
 
         # Quantized TFLite
+        MEAN = np.asarray([[[[0.485, 0.456, 0.406]]]], dtype=np.float32)
+        STD = np.asarray([[[[0.229, 0.224, 0.225]]]], dtype=np.float32)
         if output_integer_quantized_tflite:
             # Dynamic Range Quantization
             try:
@@ -772,6 +856,11 @@ def convert(
                 tflite_model = converter.convert()
                 with open(f'{output_folder_path}/model_dynamic_range_quant.tflite', 'wb') as w:
                     w.write(tflite_model)
+                if output_weights:
+                    weights_export(
+                        extract_target_tflite_file_path=f'{output_folder_path}/model_dynamic_range_quant.tflite',
+                        output_weights_file_path=f'{output_folder_path}/model_dynamic_range_quant_weights.h5',
+                    )
                 if not non_verbose:
                     print(f'{Color.GREEN}Dynamic Range Quantization tflite output complete!{Color.RESET}')
             except RuntimeError as ex:
@@ -797,25 +886,18 @@ def convert(
                 and len(model.inputs[0].shape) == 4:
 
                 # AUTO calib 4D images
-                FILE_NAME = 'calibration_image_sample_data_20x128x128x3_float32.npy'
-                DOWNLOAD_VER = '1.0.49'
-                URL = f'https://github.com/PINTO0309/onnx2tf/releases/download/{DOWNLOAD_VER}/{FILE_NAME}'
-                MEAN = np.asarray([[[[0.485, 0.456, 0.406]]]], dtype=np.float32)
-                STD = np.asarray([[[[0.229, 0.224, 0.225]]]], dtype=np.float32)
-                calib_sample_images_npy = requests.get(URL).content
-                with io.BytesIO(calib_sample_images_npy) as f:
-                    calib_data: np.ndarray = np.load(f)
-                    data_count = calib_data.shape[0]
-                    for model_input in model.inputs:
-                        calib_data_dict[model_input.name] = \
-                            [
-                                tf.image.resize(
-                                    calib_data.copy(),
-                                    (model_input.shape[1], model_input.shape[2])
-                                ),
-                                MEAN,
-                                STD,
-                            ]
+                calib_data: np.ndarray = download_test_image_data()
+                data_count = calib_data.shape[0]
+                for model_input in model.inputs:
+                    calib_data_dict[model_input.name] = \
+                        [
+                            tf.image.resize(
+                                calib_data.copy(),
+                                (model_input.shape[1], model_input.shape[2])
+                            ),
+                            MEAN,
+                            STD,
+                        ]
             elif quant_calib_input_op_name_np_data_path is not None:
                 for param in quant_calib_input_op_name_np_data_path:
                     input_op_name = str(param[0])
@@ -855,6 +937,11 @@ def convert(
                 tflite_model = converter.convert()
                 with open(f'{output_folder_path}/model_integer_quant.tflite', 'wb') as w:
                     w.write(tflite_model)
+                if output_weights:
+                    weights_export(
+                        extract_target_tflite_file_path=f'{output_folder_path}/model_integer_quant.tflite',
+                        output_weights_file_path=f'{output_folder_path}/model_integer_quant_weights.h5',
+                    )
                 if not non_verbose:
                     print(f'{Color.GREEN}INT8 Quantization tflite output complete!{Color.RESET}')
 
@@ -879,6 +966,11 @@ def convert(
                 tflite_model = converter.convert()
                 with open(f'{output_folder_path}/model_full_integer_quant.tflite', 'wb') as w:
                     w.write(tflite_model)
+                if output_weights:
+                    weights_export(
+                        extract_target_tflite_file_path=f'{output_folder_path}/model_full_integer_quant.tflite',
+                        output_weights_file_path=f'{output_folder_path}/model_full_integer_quant_weights.h5',
+                    )
                 if not non_verbose:
                     print(f'{Color.GREEN}Full INT8 Quantization tflite output complete!{Color.RESET}')
             except RuntimeError as ex:
@@ -948,7 +1040,7 @@ def convert(
         # are elementwise equal within an acceptable range.
         # https://numpy.org/doc/stable/reference/generated/numpy.allclose.html#numpy-allclose
         # numpy.allclose(a, b, rtol=1e-05, atol=1e-05, equal_nan=True)
-        if check_onnx_tf_outputs_elementwise_close:
+        if check_onnx_tf_outputs_elementwise_close or check_onnx_tf_outputs_elementwise_close_full:
             try:
                 import onnxruntime
                 import sne4onnx
@@ -970,16 +1062,80 @@ def convert(
                     f'atol={check_onnx_tf_outputs_elementwise_close_atol}, '+
                     f'equal_nan=True)')
 
+            # Listing of output_names
+            # --check_onnx_tf_outputs_elementwise_close_full lists all output names
+            # in the ONNX graph when enabled.
+            # ops_output_names is a list of output_names.
+            #
+            # output_names: List[str]
+            #
+            # ops_output_names = [
+            #   output_names,
+            #   output_names,
+            #   output_names,
+            #         :
+            # ]
+            if check_onnx_tf_outputs_elementwise_close_full:
+                ops_output_names = []
+                for graph_node in graph.nodes:
+                    ops_output_names_sub = []
+                    for graph_node_output in graph_node.outputs:
+                        ops_output_names_sub.append(graph_node_output.name)
+                    ops_output_names.extend(ops_output_names_sub)
+            else:
+                ops_output_names = output_names
+
+            # download test data
+            all_four_dim = sum(
+                [
+                    1 for input in inputs \
+                        if len(input.shape) == 4 \
+                            and input.shape[0] is not None \
+                            and input.shape[0] <= 20 \
+                            and input.shape[-1] == 3 \
+                            and input.shape[1] is not None \
+                            and input.shape[2] is not None
+                ]
+            ) == len(inputs)
+            same_batch_dim = False
+            if all_four_dim:
+                batch_size = inputs[0].shape[0]
+                for input in inputs:
+                    same_batch_dim = batch_size == input.shape[0]
+            test_data_nhwc = None
+            if all_four_dim and same_batch_dim:
+                test_data: np.ndarray = download_test_image_data()
+                test_data_nhwc = test_data[:inputs[0].shape[0], ...]
+                if check_onnx_tf_outputs_sample_data_normalization == "norm":
+                    pass
+                elif check_onnx_tf_outputs_sample_data_normalization == "denorm":
+                    test_data_nhwc = test_data_nhwc * 255.0
+
             # ONNX dummy inference
             dummy_onnx_outputs: List[np.ndarray] = dummy_onnx_inference(
                 onnx_graph=onnx_graph,
-                output_names=output_names,
+                output_names=ops_output_names,
+                test_data_nhwc=test_data_nhwc,
             )
-
             # TF dummy inference
+            del model
+            outputs = [
+                layer_info['tf_node'] \
+                    for opname, layer_info in tf_layers_dict.items() \
+                        if opname in ops_output_names \
+                            and not hasattr(layer_info['tf_node'], 'numpy')
+            ]
+            exclude_output_names = [
+                opname \
+                    for opname, layer_info in tf_layers_dict.items() \
+                        if opname in ops_output_names \
+                            and hasattr(layer_info['tf_node'], 'numpy')
+            ]
+            model = tf.keras.Model(inputs=inputs, outputs=outputs)
             dummy_tf_outputs: List[Any] = dummy_tf_inference(
                 model=model,
                 inputs=inputs,
+                test_data_nhwc=test_data_nhwc,
             )
             if not isinstance(dummy_tf_outputs, list):
                 dummy_tf_outputs = [dummy_tf_outputs]
@@ -990,14 +1146,15 @@ def convert(
             # Validation
             onnx_tensor_infos = {
                 output_name: dummy_onnx_output \
-                    for output_name, dummy_onnx_output in zip(output_names, dummy_onnx_outputs)
+                    for output_name, dummy_onnx_output in zip(ops_output_names, dummy_onnx_outputs) \
+                        if output_name not in exclude_output_names
             }
             """
             np.allclose(
                 dummy_onnx_outputs,
                 dummy_tf_outputs,
-                rtol=1e-05,
-                atol=1e-05,
+                rtol=0.0,
+                atol=1e-04,
                 equal_nan=True,
             )
 
@@ -1005,24 +1162,26 @@ def convert(
                 {
                     onnx_output_name: [
                         onnx_tensor,
-                        matched_flg, <--- True: Matched, False: Unmatched
+                        matched_flg, <--- 0: Unmatched, 1: Matched, 2: Skipped
                     ]
                 }
             """
             check_results = onnx_tf_tensor_validation(
                 onnx_tensor_infos=onnx_tensor_infos,
                 tf_tensors=dummy_tf_outputs,
-                rtol=1e-05,
-                atol=1e-05,
+                rtol=check_onnx_tf_outputs_elementwise_close_rtol,
+                atol=check_onnx_tf_outputs_elementwise_close_atol,
             )
             for onnx_output_name, checked_value in check_results.items():
                 validated_onnx_tensor: np.ndarray = checked_value[0]
-                matched_flg: bool = checked_value[1]
+                matched_flg: int = checked_value[1]
                 message = ''
-                if matched_flg:
-                    message = f'{Color.GREEN}validate_result{Color.RESET}: {Color.REVERCE}{Color.GREEN} Matches {Color.RESET}'
-                else:
+                if matched_flg == 0:
                     message = f'{Color.GREEN}validate_result{Color.RESET}: {Color.REVERCE}{Color.YELLOW} Unmatched {Color.RESET}'
+                elif matched_flg == 1:
+                    message = f'{Color.GREEN}validate_result{Color.RESET}: {Color.REVERCE}{Color.GREEN} Matches {Color.RESET}'
+                elif matched_flg == 2:
+                    message = f'{Color.GREEN}validate_result{Color.RESET}: {Color.REVERCE}{Color.BLUE} Skipped {Color.RESET}'
                 print(
                     f'{Color.GREEN}INFO:{Color.RESET} '+
                     f'{Color.GREEN}onnx_output_name{Color.RESET}: {onnx_output_name} '+
@@ -1071,7 +1230,14 @@ def main():
         '--output_h5',
         action='store_true',
         help=\
-            'Output in Keras H5 format.'
+            'Output model in Keras (hdf5) format.'
+    )
+    parser.add_argument(
+        '-ow',
+        '--output_weights',
+        action='store_true',
+        help=\
+            'Output weights in hdf5 format.'
     )
     parser.add_argument(
         '-oiqt',
@@ -1265,6 +1431,15 @@ def main():
         help=\
             'Disables FlexTranspose generation suppression.'
     )
+    parser.add_argument(
+        '-nodafc',
+        '--number_of_dimensions_after_flextranspose_compression',
+        type=int,
+        default=5,
+        help=\
+            'Number of Transpose OP dimensions generated after avoiding FlexTranspose generation. \n' +
+            'Default: 5'
+    )
     rar_group = parser.add_mutually_exclusive_group()
     rar_group.add_argument(
         '-rari64',
@@ -1413,31 +1588,70 @@ def main():
             'Run TFLite ModelAnalyzer on the generated Float16 tflite model ' +
             'to check if the model can be supported by GPU Delegate.'
     )
-    parser.add_argument(
+    coto_group = parser.add_mutually_exclusive_group()
+    coto_group.add_argument(
         '-coto',
         '--check_onnx_tf_outputs_elementwise_close',
         action='store_true',
         help=\
-            'Returns true if the two arrays, the output of onnx and the output of TF, '+
-            'are elementwise close within an acceptable range.'
+            'Returns "Matches" if the output of onnx and the output of TF are'+
+            'within acceptable proximity element by element. '+
+            'Returns "Unmatched" if the output of onnx and the output of TF are '+
+            'not within acceptable proximity element by element. '+
+            'If the output of onnx is 1D, it returns "Skipped" and skips the comparison '+
+            'between the output of onnx and that of TF. This is because when undefined '+
+            'dimensions are present, a situation often arises where very large index '+
+            'values are compared, causing OutOfMemory. '+
+            'Only the output content of the models final output OP is checked.'
+    )
+    coto_group.add_argument(
+        '-cotof',
+        '--check_onnx_tf_outputs_elementwise_close_full',
+        action='store_true',
+        help=\
+            'Returns "Matches" if the output of onnx and the output of TF are '+
+            'within acceptable proximity element by element. '+
+            'Check the output of all OPs in sequence from the beginning, '+
+            'including all but the final output OP of the model. '+
+            'Returns "Unmatched" if the output of onnx and the output of TF are '+
+            'not within acceptable proximity element by element. '+
+            'If the output of onnx is 1D, it returns "Skipped" and skips the comparison '+
+            'between the output of onnx and that of TF. This is because when undefined '+
+            'dimensions are present, a situation often arises where very large index '+
+            'values are compared, causing OutOfMemory. ' +
+            'It is very time consuming because it performs as many inferences as '+
+            'there are operations.'
+    )
+    parser.add_argument(
+        '-coton',
+        '--check_onnx_tf_outputs_sample_data_normalization',
+        type=str,
+        choices=['norm', 'denorm'],
+        default='norm',
+        help=\
+            'norm: Validate using random data normalized to the range 0.0 to 1.0 ' +
+            'denorm: Validate using random data in the range 0.0 to 255.0 ' +
+            'If there is a normalization layer at the models entry point, ' +
+            'or if the model was trained on denormalized data, "denorm" must be specified. ' +
+            'Default: "norm"'
     )
     parser.add_argument(
         '-cotor',
         '--check_onnx_tf_outputs_elementwise_close_rtol',
         type=float,
-        default=1e-5,
+        default=0.0,
         help=\
             'The relative tolerance parameter \n' +
-            'Default: 1e-5'
+            'Default: 0.0'
     )
     parser.add_argument(
         '-cotoa',
         '--check_onnx_tf_outputs_elementwise_close_atol',
         type=float,
-        default=1e-5,
+        default=1e-4,
         help=\
             'The absolute tolerance parameter \n' +
-            'Default: 1e-5'
+            'Default: 1e-4'
     )
     parser.add_argument(
         '-n',
@@ -1477,6 +1691,7 @@ def main():
         output_folder_path=args.output_folder_path,
         output_signaturedefs=args.output_signaturedefs,
         output_h5=args.output_h5,
+        output_weights=args.output_weights,
         output_integer_quantized_tflite=args.output_integer_quantized_tflite,
         quant_type=args.quant_type,
         quant_calib_input_op_name_np_data_path=calib_params,
@@ -1492,6 +1707,7 @@ def main():
         disable_group_convolution=args.disable_group_convolution,
         enable_batchmatmul_unfold=args.enable_batchmatmul_unfold,
         disable_suppression_flextranspose=args.disable_suppression_flextranspose,
+        number_of_dimensions_after_flextranspose_compression=args.number_of_dimensions_after_flextranspose_compression,
         replace_argmax_to_reducemax_and_indicies_is_int64=args.replace_argmax_to_reducemax_and_indicies_is_int64,
         replace_argmax_to_reducemax_and_indicies_is_float32=args.replace_argmax_to_reducemax_and_indicies_is_float32,
         replace_argmax_to_fused_argmax_and_indicies_is_int64=args.replace_argmax_to_fused_argmax_and_indicies_is_int64,
@@ -1510,6 +1726,8 @@ def main():
         param_replacement_file=args.param_replacement_file,
         check_gpu_delegate_compatibility=args.check_gpu_delegate_compatibility,
         check_onnx_tf_outputs_elementwise_close=args.check_onnx_tf_outputs_elementwise_close,
+        check_onnx_tf_outputs_elementwise_close_full=args.check_onnx_tf_outputs_elementwise_close_full,
+        check_onnx_tf_outputs_sample_data_normalization=args.check_onnx_tf_outputs_sample_data_normalization,
         check_onnx_tf_outputs_elementwise_close_rtol=args.check_onnx_tf_outputs_elementwise_close_rtol,
         check_onnx_tf_outputs_elementwise_close_atol=args.check_onnx_tf_outputs_elementwise_close_atol,
         mvn_epsilon=args.mvn_epsilon,
